@@ -46,69 +46,84 @@ PROJECT_ROOT = Path(__file__).parent.parent.parent
 
 
 def test_changelog():
-    with PROJECT_ROOT.joinpath('CHANGES.rst').resolve().open() as doc:
+    with PROJECT_ROOT.joinpath("changelog.rst").resolve().open() as doc:
         content = doc.read()
 
     assert content.startswith("Changelog\n=========\n")
 
     entry_pattern = re.compile(r"^\* \[(?P<category>[a-z,]+)\] (?P<entry>.+)")
     for line in content.splitlines():
-        if line.startswith('*'):
+        if line.startswith("*"):
             match = entry_pattern.match(line)
             assert match
             entry = match.groupdict()
-            assert entry['category']
-            assert set(entry['category'].split(',')).issubset(flatten([
-                MANAGER_IDS, OS_DEFINITIONS.keys(), 'mpm', 'bitbar']))
+            assert entry["category"]
+            assert set(entry["category"].split(",")).issubset(
+                flatten([MANAGER_IDS, OS_DEFINITIONS.keys(), "mpm", "bitbar"])
+            )
 
 
 def test_labeller_rules():
 
     # Extract list of canonically defined labels.
-    with PROJECT_ROOT.joinpath('.github/labels.json').resolve().open() as doc:
+    with PROJECT_ROOT.joinpath(".github/labels.json").resolve().open() as doc:
         content = doc.read()
-    defined_labels = [lbl['name'] for lbl in json.loads(content)]
+    defined_labels = [lbl["name"] for lbl in json.loads(content)]
 
     # Canonical labels are uniques.
     assert len(defined_labels) == len(set(defined_labels))
     canonical_labels = set(defined_labels)
 
     # Extract and categorize labels.
-    canonical_managers = {lbl for lbl in canonical_labels
-                          if lbl.startswith('manager: ') and 'mpm' not in lbl}
-    canonical_platforms = {lbl for lbl in canonical_labels
-                           if lbl.startswith('platform: ')}
+    canonical_managers = {
+        lbl
+        for lbl in canonical_labels
+        if lbl.startswith("manager: ") and "mpm" not in lbl
+    }
+    canonical_platforms = {
+        lbl for lbl in canonical_labels if lbl.startswith("platform: ")
+    }
     assert canonical_managers
     assert canonical_platforms
 
     # Extract rules from json blurb serialized into YAML.
     with PROJECT_ROOT.joinpath(
-            '.github/workflows/labels_issue.yaml').resolve().open() as doc:
+        ".github/workflows/labeller-content-based.yaml"
+    ).resolve().open() as doc:
         content = doc.read()
     assert "Naturalclar/issue-action" in content
-    json_rules = load(content, Loader=Loader)[
-        'jobs']['labeller']['steps'][0]['with']['parameters']
+    json_rules = load(content, Loader=Loader)["jobs"]["labeller"]["steps"][1]["with"][
+        "parameters"
+    ]
     rules = json.loads(json_rules)
     assert rules
 
     # Each keyword match one rule only.
-    rules_keywords = Counter(flatten([r['keywords'] for r in rules]))
+    rules_keywords = Counter(flatten([r["keywords"] for r in rules]))
     assert rules_keywords
     assert max(rules_keywords.values()) == 1
 
     # Extract and categorize labels.
-    rules_labels = Counter(flatten([r['labels'] for r in rules]))
+    rules_labels = Counter(flatten([r["labels"] for r in rules]))
 
     assert rules_labels
     # Check that all labels are canonically defined.
     assert canonical_labels.issuperset(rules_labels)
 
-    rules_managers = Counter({
-        label: count for label, count in rules_labels.items()
-        if label.startswith('manager: ')})
-    rules_platforms = Counter({
-        label: count for label, count in rules_labels.items()
-        if label.startswith('platform: ')})
+    rules_managers = Counter(
+        {
+            label: count
+            for label, count in rules_labels.items()
+            if label.startswith("manager: ")
+        }
+    )
+    rules_platforms = Counter(
+        {
+            label: count
+            for label, count in rules_labels.items()
+            if label.startswith("platform: ")
+        }
+    )
 
     assert rules_managers
     # Each canonical manager labels is defined.
@@ -131,10 +146,10 @@ def test_labeller_rules():
     for rule in rules:
 
         # No duplicate labels.
-        assert len(set(rule['labels'])) == len(rule['labels'])
+        assert len(set(rule["labels"])) == len(rule["labels"])
 
         # Special checks for rules targetting manager labels.
-        manager_label = canonical_managers.intersection(rule['labels'])
+        manager_label = canonical_managers.intersection(rule["labels"])
         if manager_label:
 
             # Extract manager label
@@ -142,7 +157,7 @@ def test_labeller_rules():
             manager_label = manager_label.pop()
 
             # Only platforms are expected alongside manager labels.
-            platforms = set(rule['labels']) - canonical_managers
+            platforms = set(rule["labels"]) - canonical_managers
             assert platforms.issubset(canonical_platforms)
 
             # Check managers sharing the same label shares the same platforms.
@@ -151,10 +166,12 @@ def test_labeller_rules():
                 for mid, lbl in MANAGER_LABELS.items()
                 # Relying on pool() restrict our checks, as the pool exclude
                 # non-locally supported managers.
-                if lbl == manager_label and mid in pool()]
+                if lbl == manager_label and mid in pool()
+            ]
             assert len(set(supported_platforms)) == 1
 
             # Check the right platforms is associated with the manager.
             supported_platform_labels = {
-                PLATFORM_LABELS[os_label(p)] for p in supported_platforms[0]}
+                PLATFORM_LABELS[os_label(p)] for p in supported_platforms[0]
+            }
             assert platforms == supported_platform_labels
